"""add tenant

Revision ID: 5e805b526efa
Revises: 9249428e19b0
Create Date: 2024-08-07 18:33:29.324780

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
import core.db_models.utils
from core.utils import current_utc_time, generate_unique_identifier_key


# revision identifiers, used by Alembic.
revision: str = '5e805b526efa'
down_revision: Union[str, None] = '9249428e19b0'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('tenant',
    sa.Column('uuid', sa.String(length=36), nullable=True),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.Integer(), nullable=False),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_tenant_id'), 'tenant', ['id'], unique=False)
    # ### end Alembic commands ###
    # ### Inserting default tenant
    connection = op.get_bind()
    connection.execute(
        sa.text("""
                INSERT INTO tenant (status, create_time, update_time, uuid)
                VALUES 
                    (1, :now, :now, :uuid)
            """),
        {"now": current_utc_time(), "uuid": generate_unique_identifier_key()}
    )


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_tenant_id'), table_name='tenant')
    op.drop_table('tenant')
    # ### end Alembic commands ###
