"""Added evaluation tables

Revision ID: 701ddf55a1b4
Revises: a95b604c47fb
Create Date: 2025-02-20 12:12:01.526199

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
import core.db_models.utils


# revision identifiers, used by Alembic.
revision: str = '701ddf55a1b4'
down_revision: Union[str, None] = 'a95b604c47fb'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('eval_config',
    sa.Column('name', sa.String(length=255), nullable=True),
    sa.Column('purpose', sa.Text(), nullable=True),
    sa.Column('application_ids', sa.String(length=255), nullable=True),
    sa.Column('application_names', sa.Text(), nullable=True),
    sa.Column('categories', sa.Text(), nullable=True),
    sa.Column('custom_prompts', sa.Text(), nullable=True),
    sa.Column('version', sa.Integer(), nullable=False),
    sa.Column('owner', sa.String(length=255), nullable=True),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_config_id'), 'eval_config', ['id'], unique=False)
    op.create_table('eval_run',
    sa.Column('name', sa.String(length=255), nullable=False),
    sa.Column('owner', sa.String(length=255), nullable=False),
    sa.Column('purpose', sa.Text(), nullable=True),
    sa.Column('eval_id', sa.String(length=255), nullable=False),
    sa.Column('config_id', sa.String(length=255), nullable=False),
    sa.Column('config_name', sa.String(length=255), nullable=True),
    sa.Column('application_names', sa.Text(), nullable=True),
    sa.Column('cumulative_result', sa.Text(), nullable=True),
    sa.Column('passed', sa.String(length=255), nullable=True),
    sa.Column('failed', sa.String(length=255), nullable=True),
    sa.Column('base_run_id', sa.String(length=255), nullable=True),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_run_id'), 'eval_run', ['id'], unique=False)
    op.create_table('eval_config_history',
    sa.Column('name', sa.String(length=255), nullable=True),
    sa.Column('purpose', sa.Text(), nullable=True),
    sa.Column('application_ids', sa.String(length=255), nullable=True),
    sa.Column('application_names', sa.Text(), nullable=True),
    sa.Column('generated_config', sa.Text(), nullable=True),
    sa.Column('categories', sa.Text(), nullable=True),
    sa.Column('custom_prompts', sa.Text(), nullable=True),
    sa.Column('version', sa.Integer(), nullable=False),
    sa.Column('owner', sa.String(length=255), nullable=True),
    sa.Column('eval_config_id', sa.Integer(), nullable=False),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.ForeignKeyConstraint(['eval_config_id'], ['eval_config.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_config_history_id'), 'eval_config_history', ['id'], unique=False)
    op.create_table('eval_result_prompt',
    sa.Column('eval_run_id', sa.Integer(), nullable=False),
    sa.Column('eval_id', sa.String(length=255), nullable=False),
    sa.Column('prompt_uuid', sa.String(length=255), nullable=False, unique=True),
    sa.Column('prompt', sa.Text(), nullable=False),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.ForeignKeyConstraint(['eval_run_id'], ['eval_run.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_result_prompt_id'), 'eval_result_prompt', ['id'], unique=False)
    op.create_table('eval_target',
    sa.Column('application_id', sa.Integer(), nullable=True),
    sa.Column('config', sa.JSON(), nullable=False),
    sa.Column('name', sa.String(length=255), nullable=True),
    sa.Column('url', sa.Text(), nullable=True),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.ForeignKeyConstraint(['application_id'], ['ai_application.id'], ),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_target_id'), 'eval_target', ['id'], unique=False)
    op.create_table('eval_result_response',
    sa.Column('eval_run_id', sa.Integer(), nullable=False),
    sa.Column('eval_result_prompt_uuid', sa.String(length=255), nullable=False),
    sa.Column('eval_id', sa.String(length=255), nullable=False),
    sa.Column('response', sa.Text(), nullable=True),
    sa.Column('application_name', sa.String(length=255), nullable=False),
    sa.Column('failure_reason', sa.Text(), nullable=True),
    sa.Column('category_score', sa.Text(), nullable=True),
    sa.Column('category', sa.String(length=255), nullable=True),
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('create_time', sa.DateTime(), nullable=True),
    sa.Column('update_time', sa.DateTime(), nullable=True),
    sa.Column('status', sa.String(length=255), nullable=True),
    sa.ForeignKeyConstraint(['eval_result_prompt_uuid'], ['eval_result_prompt.prompt_uuid'], ),
    sa.ForeignKeyConstraint(['eval_run_id'], ['eval_run.id'], ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_eval_result_response_id'), 'eval_result_response', ['id'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_eval_result_response_id'), table_name='eval_result_response')
    op.drop_table('eval_result_response')
    op.drop_index(op.f('ix_eval_target_id'), table_name='eval_target')
    op.drop_table('eval_target')
    op.drop_index(op.f('ix_eval_result_prompt_id'), table_name='eval_result_prompt')
    op.drop_table('eval_result_prompt')
    op.drop_index(op.f('ix_eval_config_history_id'), table_name='eval_config_history')
    op.drop_table('eval_config_history')
    op.drop_index(op.f('ix_eval_run_id'), table_name='eval_run')
    op.drop_table('eval_run')
    op.drop_index(op.f('ix_eval_config_id'), table_name='eval_config')
    op.drop_table('eval_config')
    # ### end Alembic commands ###
